@@ -29,6 +29,12 @@ from monasca_notification.conf import queues
 from monasca_notification.conf import retry
 from monasca_notification.conf import statsd
 from monasca_notification.conf import zookeeper
+from monasca_notification.plugins import email_notifier
+from monasca_notification.plugins import hipchat_notifier
+from monasca_notification.plugins import jira_notifier
+from monasca_notification.plugins import pagerduty_notifier
+from monasca_notification.plugins import slack_notifier
+from monasca_notification.plugins import webhook_notifier
 
 LOG = log.getLogger(__name__)
 CONF = cfg.CONF
@@ -54,7 +60,19 @@ def register_opts(conf=None):
         m.register_opts(conf)
 
 
+def register_enabled_plugin_opts(conf=None):
+    if conf is None:
+        conf = CONF
+    for enabled_plugin in conf.notification_types.enabled:
+        ep_module = importutils.import_module(".".join(enabled_plugin.split(".")[:-1]))
+        ep_module.register_opts(conf)
+
+
 def list_opts():
+    PLUGIN_CONF_OPTS = [slack_notifier, jira_notifier,
+                        hipchat_notifier, email_notifier,
+                        webhook_notifier, pagerduty_notifier]
+    CONF_OPTS.extend(PLUGIN_CONF_OPTS)
     opts = collections.defaultdict(list)
     for m in CONF_OPTS:
         configs = copy.deepcopy(m.list_opts())
@@ -80,21 +98,6 @@ def load_from_yaml(yaml_config, conf=None):
         notifiers_cfg = {t.lower(): v for t, v in notifiers_cfg.items()}
         enabled_plugins = notifiers_cfg.pop('plugins', [])
 
-        # We still can have these 3 (email, pagerduty, webhook)
-        #  that are considered as builtin, hence should be always enabled
-        conf_to_plugin = {
-            'email': 'monasca_notification.plugins.'
-                     'email_notifier:EmailNotifier',
-            'pagerduty': 'monasca_notification.plugins.'
-                         'pagerduty_notifier:PagerdutyNotifier',
-            'webhook': 'monasca_notification.plugins.'
-                       'webhook_notifier:WebhookNotifier'
-        }
-        for ctp_key, ctp_clazz in conf_to_plugin.items():
-            if ctp_key in notifiers_cfg and ctp_key not in enabled_plugins:
-                LOG.debug('%s enabled as builtin plugin', ctp_key)
-                enabled_plugins.append(ctp_clazz)
-
         _plain_override(g='notification_types', enabled=enabled_plugins)
         if not enabled_plugins:
             return
